# Sofar Ocean API Python Client
Python Client for the Sofar Ocean Spotter API

### Requirements
- Python3
- pysofar
- numpy
- Pytest (If developing/Contributing)
- Setuptools (If developing/Contributing)

### Installation
1. Make sure that you have the requirements listed above
2. `pip install roguewave` to your desired python environment
3. Test with `python3 -c 'import roguewave'`. If this runs successfully, chances are everything worked.
